<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Calendar;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Input;
use Session;
use Redirect;
use App\Classes\Helper;
use View;
use Entrust;
use QrCode;
use App\User;
use App\Role;
use App\ChargingHistory;
use App\Permission;
use App\AppUser;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return $this->dashboard();	
    }
    public function dashboard()
    {
        
    // Users registred counts by month  
   $usersa = AppUser::selectRaw("COUNT(*) count, DATE_FORMAT(created_at, '%m') date")
    ->whereYear('created_at', Carbon::now()->year)
    ->groupBy('date')
    ->get();      
    $usermcount = [];
    $userArr = [];
    foreach ($usersa as $key => $value) {
        $usermcount[(int)$value->date] = $value->count;
    }
    for($i = 1; $i <= 12; $i++){
        if(!empty($usermcount[$i])){
            $userArr[] = $usermcount[$i];    
        }else{
            $userArr[] = 0;    
        }
    }
   $userscount=json_encode($userArr);


    //sales graph by monthly
    $sales = ChargingHistory::selectRaw("sum(amount) amount, DATE_FORMAT(created_at, '%m') date")
    ->whereYear('created_at', Carbon::now()->year)
    ->groupBy('date')
    ->get();      
    $salescount = [];
    $salesArr = [];
    foreach ($sales as $key => $value) {
        $salescount[(int)$value->date] = $value->amount;
    }
    for($i = 1; $i <= 12; $i++){
        if(!empty($salescount[$i])){
            $salesArr[] = $salescount[$i];    
        }else{
            $salesArr[] = 0;    
        }
    }
     $sales=json_encode($salesArr);

         //consumption graph by monthly
    $power = ChargingHistory::selectRaw("sum(power_usage) power_usage, DATE_FORMAT(created_at, '%m') date")
    ->whereYear('created_at', Carbon::now()->year)
    ->groupBy('date')
    ->get();      
    $powercount = [];
    $powerArr = [];
    foreach ($power as $key => $value) {
        $powercount[(int)$value->date] = (int)$value->power_usage;
    }
    for($i = 1; $i <= 12; $i++){
        if(!empty($powercount[$i])){
            $powerArr[] = $powercount[$i];    
        }else{
            $powerArr[] = 0;    
        }
    }
     $consumption=json_encode($powerArr);

 
     //Users registrations in Present Month
       $user=AppUser::whereYear('created_at', Carbon::now()->year);
       if(Entrust::hasRole('organisation'))
       $user->where('package_name',Auth::user()->package);

       $users=$user->whereMonth('created_at', Carbon::now()->month)->get()->count();

    //Users registrations in last Month
        $lastmonthth=AppUser::whereYear('created_at', Carbon::now()->year);
        if(Entrust::hasRole('organisation'))
        $lastmonthth->where('package_name',Auth::user()->package);

        $lastmonth=$lastmonthth->whereMonth('created_at', Carbon::today()->subMonth()->endOfMonth())->get()->count();

    //Users registrations in last 2 Month
       $beforelastm=AppUser::whereYear('created_at', Carbon::now()->year);
       if(Entrust::hasRole('organisation'))
       $beforelastm->where('package_name',Auth::user()->package);
       
       $beforelastmonth=$beforelastm->whereMonth('created_at', Carbon::create()->endOfMonth()->modify('-2 month'))->get()->count();
       

      //sales on today
      $todaysales=DB::table('charging_histories')
      ->whereYear('created_at', Carbon::now()->year)
      ->whereMonth('created_at',Carbon::now()->month)
      ->whereDay('created_at', Carbon::now()->day)
      ->sum('amount');

   $yesterdaysales=DB::table('charging_histories')
   ->whereYear('created_at', Carbon::now()->year)
   ->whereMonth('created_at',Carbon::now()->month)
   ->whereDay('created_at', Carbon::yesterday()->day)
   ->sum('amount');

   $daybeforeyesterdaysales=DB::table('charging_histories')
   ->whereYear('created_at', Carbon::now()->year)
   ->whereMonth('created_at',Carbon::now()->month)
   ->whereDay('created_at',Carbon::today()->previous(6)->addDay())
   ->sum('amount');
   $visit_count=\App\RequestsTracker::where('date',date('Y-m-d'))->get()->count();
   $yes_visit_count=\App\RequestsTracker::where('date',date('Y-m-'.Carbon::yesterday()->day))->get()->count();

   $percentage= $this->diff_percent($yes_visit_count, $visit_count);


    //Stations Status count activity banned etc
    if(Entrust::hasRole('organisation'))
    $usage = DB::table('stations')->select('status',DB::raw('count(*) as total'))->where('application',Auth::user()->package)->groupBy('status')->get();
    else
    $usage = DB::table('stations')->select('status',DB::raw('count(*) as total'))->groupBy('status')->get();
      
        
        
        $title="Dashboard";
        $menu['menu']="dashboard";
        return view('home',compact('title','menu','lastmonth','beforelastmonth','percentage','visit_count','yes_visit_count','yesterdaysales','daybeforeyesterdaysales','userscount','consumption','sales','usage','users','todaysales'));     
		
    }

    function diff_percent($a, $b) {
    try{
        if($a!=0 &&  $b!=0){
            $c = ($a > $b) ? ($a-$b)/$a*-100 : ($b-$a)/$b*100; 
            return round($c, 2);
        }
        return 0;
      
        
    
    }catch(DivisionByZeroError $e){
            return 0;
        }
    }
    


    public function recentRegisteredUsers(){
        $user=AppUser::whereYear('created_at', Carbon::now()->year);
        if(Entrust::hasRole('organisation'))
        $users=$user->where('package_name',Auth::user()->package);

       return $users=$user->whereMonth('created_at', Carbon::now()->month)
        ->orderBy('id','DESC')
        ->limit('10')
        ->get();


    }




    // 'performance_schema','phpmyadmin',
function databases_count(){
    $data= DB::select("select count(*) as count from information_schema.SCHEMATA where schema_name not in ('mysql','information_schema')");
    return json_encode($data);
    }





    public function recentActivity(){

     
		
       $activities = \App\Activity::select('user_id', 'module', 'unique_id', 'secondary_id', 'activity','user as id','created_at')->orderBy('created_at','desc')->take('50')->get();

        $data = '<ul class="media-list" style="margin-left: -38px;">';
        foreach($activities as $activity){

            if($activity->activity == 'activity_added')
            $description = trans('New').' '.trans('messages.'.$activity->module).' '.trans('messages.'.$activity->activity);
        else
            $description = trans('messages.'.$activity->module).' '.trans('messages.'.$activity->activity);
                $role='';
                $fullname='';
                if($activity->id==0){
                    if($activity->user){
                $fullname=$activity->user->fullname;
                 $role="Admin";
                    }
                }else{
                    $fr=\App\Franchise::find($activity->user_id);
                    $fullname=$fr->first_name.' '.$fr->last_name;
                    $role="Franchise";
                }
                $tooltip = $fullname;
            $data .= '<li class="media">
            <a class="pull-left" href="#"><div class="textAvatar profile-avatar" data-toggle="tooltip" title="'.$tooltip.'">'.$fullname.'</div></a>
                <div class="media-body">
                  <h6 class="media-heading"><a href="#">'.$fullname.'</a> <span class="pull-right"><small>'.showDateTime($activity->created_at).'</small></span></h6>
                  <p><i class="'.(config('icons.'.$activity->module) ? : 'fa fa-bars').' icon"></i> '.$description.'</p>
                </div>
            </li>';
        }
        $data .= '</ul>';

        return $data;
   }
}
