<?php


namespace App\Http\Controllers;


use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use DB;
use Session;
use App\Http\Requests\RoleRequest;
use App\Permission;
use App\Role;
use App\Classes\Helper;
use Validator;
use Entrust;
use Datatables;

class RoleController extends Controller
{
    use BasicController;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
       $this->middleware('auth');
       
    }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

       if(!Entrust::can('role-manage'))
       return view('common.error',['message' => trans('messages.permission_denied')]);
         
        $menu=['masters'];
        $roles = Role::orderBy('id','DESC')->paginate(5);
        return view('roles.index',compact('roles','menu'))->with('i', ($request->input('page', 1) - 1) * 5);
   
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('roles.create',compact(['']));
    }
	public function lists(Request $request){

        

        $menu=['masters'];


        $draw = $request->get('draw');
        $start = $request->get('start');
        $length = $request->get('length');

        DB::statement(DB::raw('set @rownum=0'));
        $roles = Role::get(['roles.*', 
        DB::raw('@rownum  := @rownum  + 1 AS rownum')]);
           // return Datatables::of(Role::query())->make(true);

            return Datatables::of($roles)
            ->addColumn('action', function ($roles) {
            return ' <div class="btn-group btn-group-xs"> <td>
              <a href="#" data-href="/roles/'.$roles->id.'/edit" class="edit-form" data-toggle="modal" data-target="#mymodel"> <i class="icon ion-edit tx-20 icon-properties edit" ></i></a>
             </div>';

            //  .delete_form(['roles.destroy',$roles->id],'roles','1').
            })
            ->removeColumn('id')
            ->addIndexColumn()
          
            ->make(true);
 
	}

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(RoleRequest $request,Role $role)
    {
        
       if(!Entrust::can('role-create'))
       return view('common.error',['message' => trans('messages.permission_denied')]);

		$role->fill($request->all())->save();	
        if($request->has('is_default')){
        	\App\Role::whereNotNull('id')->update(['is_default' => 0]);
        	$role->is_default = 1;
        	$role->save();
        }
        $this->logActivity(['module' => 'roles','activity' => 'activity_added']);
		return redirect('/roles')->withSuccess(trans('messages.role').' '.trans('messages.added'));
    }




    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(!Entrust::can('role-manage'))
        return view('common.error',['message' => trans('messages.permission_denied')]);

        $role = Role::find($id);
        $menu=['masters'];
        $rolePermissions = Permission::join("permission_role","permission_role.permission_id","=","permissions.id")
            ->where("permission_role.role_id",$id)
            ->get();


        return view('roles.index',compact('roles','rolePermissions','menu'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
	public function edit(Role $role){

        if(!Entrust::can('role-edit'))
        return view('common.error',['message' => trans('messages.permission_denied')]);

		return view('roles.edit',compact('role'));
	}


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(RoleRequest $request, Role $role){

        if(!Entrust::can('role-edit'))
        return view('common.error',['message' => trans('messages.permission_denied')]);

		$role->name = $request->input('name');
		$role->save();

        if($request->has('is_default')){
        	\App\Role::whereNotNull('id')->update(['is_default' => 0]);
        	$role->is_default = 1;
        	$role->save();
        }

		$this->logActivity(['module' => 'role','unique_id' => $role->id,'activity' => 'activity_updated']);

        if($request->has('ajax_submit')){
        	$data = $this->lists();
	        $response = ['message' => trans('messages.role').' '.trans('messages.updated'), 'status' => 'success','data' => $data]; 
	        return response()->json($response, 200, array('Access-Controll-Allow-Origin' => '*'));
	    }

		return redirect('/roles')->withSuccess(trans('messages.role').' '.trans('messages.updated'));
	}

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // DB::table("roles")->where('id',$id)->delete();

    if(!Entrust::can('role-delete'))
    return view('common.error',['message' => trans('messages.permission_denied')]);

    

      $roles = Role::find($id);
      $roles->delete();

      Session::flash('success', 'Successfully Deleted!');
      return redirect()->route('roles.index')->with('success','Role deleted successfully');
    }




    public function getRoles(Request $request)
    {
        return Role::where(['department_id'=>$request->department,'designation_id'=>$request->designation,'level_id'=>$request->level])->get();
    }
}