<?php
namespace App\Http\Controllers;
use Entrust;
use Auth;
use File;
use Mail;
use App\Classes\Helper;
use Illuminate\Http\Request;
use Validator;
use App\Template;

Class TemplateController extends Controller{
    use BasicController;

	public function index(Template $template){

        $col_heads = array(
        		
        		trans('messages.name'),
        		trans('messages.category'),
				trans('messages.subject'),
				trans('messages.option'),
        		);

		$category = array();

		$templates = Template::all();

		$insert = array();
		foreach(config('template') as $key => $value){
			$find_template = $templates->where('category',$key)->count();
			if($find_template == 0){
				$body = File::get(base_path().'/resources/views/'.$value['path'].'.blade.php');
				$insert[] = array('is_default' => 1,'name' => Helper::toWord($key),'subject' => $value['default_subject'], 'body' => $body,'category' => $key);
			}
		}

	
		if(count($insert))
			Template::insert($insert);

		foreach(config('template-field') as $key => $value)
			if($key != 'forgot_password' && $key != 'welcome_email')
			$category[$key] = ucwords($key);

        $table_info = array(
			'source' => 'templates',
			'title' => 'Template List',
			'id' => 'template_table'
		);
		return view('admin.template.index',compact('col_heads','table_info','category'));
	}


//display data into table using AJAX Request
	public function lists(Request $request){

		$columns = array( 
            0 =>'name',
            1=> 'category',
            2=> 'subject',
            4=> 'status',
 
        );

    $totalData = \App\Template::count();

    $totalFiltered = $totalData; 

    $limit = $request->input('length');
    $start = $request->input('start');
    $order = $columns[$request->input('order.0.column')];
    $dir = $request->input('order.0.dir');

    if(empty($request->input('search.value')))
    {            
    $template = \App\Template::offset($start)
            ->limit($limit)
            ->orderBy($order,$dir)
            ->get();
    }
else {
$search = $request->input('search.value'); 

$template =  \App\Template::where('name','LIKE',"%{$search}%")
			->orWhere('category', 'LIKE',"%{$search}%")
			->orWhere('subject', 'LIKE',"%{$search}%")
            ->offset($start)
            ->limit($limit)
            ->orderBy($order,$dir)
            ->get();

$totalFiltered = \App\Template::where('name','LIKE',"%{$search}%")
             ->orWhere('category', 'LIKE',"%{$search}%")
             ->orWhere('subject', 'LIKE',"%{$search}%")
             ->count();
}
$rows=[];
    $data = array();
    $i=1;
    if(!empty($template))
    {
        $i=1;
    foreach ($template as $template){
        $rows[] = array(
			$template->name,
			Helper::toWord($template->category),
			$template->subject,
			'<div class="btn-group btn-group-xs">'.
			'<a href="#" data-href="/templates/'.$template->id.'/edit" class="btn btn-xs btn-default edit-form" data-toggle="modal" data-target="#mymodel"> <i class="fa fa-edit" data-toggle="tooltip" title="'.trans('messages.edit').'"></i></a> '.
			(!$template->is_default ? delete_form(['templates.destroy',$template->id],'template',1) : '').
			'</div>',
			);  
          $i++;
        }
}
$json_data = array(
    "draw"            => intval($request->input('draw')),  
    "recordsTotal"    => intval($totalData),  
    "recordsFiltered" => intval($totalFiltered), 
    "aaData"            => $rows   
    );
echo json_encode($json_data); 
        
	}




	public function create(){
		
	}

	public function edit(Template $template){
		return view('admin.template.edit',compact('template'));
	}

	public function store(Request $request, Template $template){

        $validation = Validator::make($request->all(),[
            'category' => 'required',
            'name' => 'required|unique:templates,name'
        ]);

        if($validation->fails()){
           
            return redirect()->back()->withInput()->withErrors($validation->messages());
        }

		$data = $request->all();
		$template->fill($data)->save();
		$this->logActivity(['module' => 'template','activity' => 'activity_added']);

      
		return redirect()->back()->withSuccess(trans('messages.template').' '.trans('messages.saved'));
	}
	

	public function update(Request $request,Template $template){

        $validation = Validator::make($request->all(),[
            'subject' => 'required',
            'body' => 'required'
		]);
		

		// return $request;

        if($validation->fails()){
           
            return redirect()->back()->withInput()->withErrors($validation->messages());
        }

        $template->subject = $request->input('subject');
        $template->body = $request->input('body');
        $template->save();

		$this->logActivity(['module' => 'template','activity' => 'activity_updated']);

	   
		return redirect('/templates')->withSuccess(trans('messages.template').' '.trans('messages.saved'));
	}

	public function destroy(Template $template,Request $request){

		if($template->is_default){
	       
			return redirect()->back()->withErrors(trans('messages.template_cannot_delete'));
		}

        $template->delete();
		$this->logActivity(['module' => 'template','activity' => 'activity_deleted']);

	   
    	return redirect()->back()->withSuccess(trans('messages.template').' '.trans('messages.deleted'));
	}
}
?>