<?php

namespace App\Http\Controllers;
use DB;
use Illuminate\Http\Request;
use Validator;
use Entrust;
use Auth;
use App\Classes\Helper;

class Transactions extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        if(!Entrust::can('view_transactions'))
        return view('common.error',['message' => trans('messages.permission_denied')]);


        if(Entrust::hasRole('organisation')){
        $stations = \App\Station::where('application',Auth::user()->package)->get()->pluck('station_name',"station_id")->all();
        $charging_points    =\App\StationNozzle::join('stations','stations.station_id','=','station_nozzles.station_id')->where('application',Auth::user()->package)->get()->pluck('nozzle_id','nozzle_id')->all();
             
        } else{
        $stations =\App\Station::get()->pluck('station_name',"station_id")->all();
        $charging_points    =\App\StationNozzle::get()->pluck('nozzle_id','nozzle_id')->all();
         }


       
        $todaydate         =    date('Y-m-d');
        $search='';
        $active='bydate';
        $transactions='';
        $message='';


        if($request->search){
            $transactions=\App\Transaction::
            select('transactions.station_id','transactions.trans_id','transactions.order_id','transaction_time','transaction_date',
            'stations.location_name','stations.station_name','amount','transactions.charger_id')
            ->join('stations','transactions.station_id','=','stations.station_id');
            
     
        if($request->search=='bydate'){
        $validation = Validator::make($request->all(),[
                'startDate' => 'required','endDate'   => 'required']);
        if($validation->fails()){ 
            return redirect()->back()->withInput()->withErrors($validation->messages());
        }
        $application    =   $request->application;
        $station        =   $request->station;
        $cps            =   $request->cps;
        $startDate      =   $request->startDate;
        $endDate        =   $request->endDate;
        $search=true;

        view()->share(compact('application','station','cps'));
        $active='bydate';
        $message=$startDate .' To '. $endDate;


        if(!empty($cps)){
            $transactions->join('station_nozzles','station_nozzles.nozzle_id','=','transactions.ocpp_id');
            $transactions->where('transactions.ocpp_id',$cps);
            $message="Ocpp Id :".$cps." , ".$message;
        }
        
        if(!empty($station)){
            $transactions->where('stations.station_id',$station);
            $message=" Station : ".$station."  ".$message;
        }
        if(!empty($application)){
            $transactions->where('stations.application',$application);
            $message="Package :".ucfirst($application)." , ".$message;
        }
        $transactions->whereBetween('transactions.created_at', 
        array(date('Y-m-d 00:00:00',strtotime($startDate)),date('Y-m-d 23:59:59',strtotime($endDate))));
        }
        if($request->search=='bymonth'){
            
            
            $validation = Validator::make($request->all(),[
                'from_month' => 'required','to_month'   => 'required']);
        if($validation->fails()){ 
            return redirect()->back()->withInput()->withErrors($validation->messages());
        }
        
        $applications    =   $request->applications;
        $station        =   $request->stations;
        $cpss            =   $request->cpss;
        $startDate      =   $request->from_month;
        $endDate        =   $request->to_month;

        $from_month     =$startDate ;
        $to_month       =$endDate ;
        $search=true;

        view()->share(compact('applications','station','cpss','from_month' ,'to_month'));
        $active='bymonth';
        $message=" Date : ".$startDate .' To '. $endDate;


        if(!empty($cpss)){
             $transactions->join('station_nozzles','station_nozzles.nozzle_id','=','transactions.ocpp_id');
            $transactions->where('transactions.ocpp_id',$cpss);
             $message="Ocpp Id :".$cpss." , ".$message;
        }
        
        if(!empty($station)){
             $transactions->where('stations.station_id',$station);
             $message=" Station : ".$station."  ".$message;
        }
        if(!empty($applications)){
             $transactions->where('stations.application',$applications);
            $message="Package :".ucfirst($applications)." , ".$message;
        }

        // return  array(
        //     date('Y-m-d',strtotime('01-'.$startDate)),
        //     date('Y-m-d',strtotime('01-'.$endDate))
        // );
        $end    = date('Y-m-d',strtotime('01-'.$endDate));
        $strt   = date('Y-m-d',strtotime('01-'.$startDate));

        $transactions->raw("where `transactions`.`transaction_date` between '$strt' and '$end'");

       }
        
            $transactions=$transactions->get();
            $menu['menu']='reports';
            return view('admin.transactions.user_transactions',compact('charging_points','packages',"stations",'endDate','startDate','message','search','active','menu','transactions'));
        }

        $menu['menu']='reports';
        return view('admin.transactions.user_transactions',compact('charging_points','packages',"stations",'message','search','active','menu','transactions'));
   
    }






    public function chargingReport(Request $request)
    {

        if(!Entrust::can('view_charging_report'))
        return view('common.error',['message' => trans('messages.permission_denied')]);



        

        try{

        
        if(Entrust::hasRole('organisation')){
         $stations = \App\Station::where('application',Auth::user()->package)->get()->pluck('station_name',"station_id")->all();
         $charging_points    =\App\StationNozzle::join('stations','stations.station_id','=','station_nozzles.station_id')->where('application',Auth::user()->package)->get()->pluck('nozzle_id','nozzle_id')->all();        
        } else{
         $stations =\App\Station::get()->pluck('station_name',"station_id")->all();
         $charging_points    =\App\StationNozzle::get()->pluck('nozzle_id','nozzle_id')->all();
        }


        $todaydate         =    date('Y-m-d');
        $search='';
        $active='bydate';
        $transactions='';
        $message='';         
        $menu['menu']='reports';

       $fromdate       = '';
       $todate         =    date('D-m-Y');
       $startDate      =   '';
       $endDate        =   '';
       $searchdata     =   '';



       if($request->search){
  
        if($request->search=='byuser'){
            $active='byuser';
            $validation = Validator::make($request->all(),[
                'startDate' => 'required',
                'endDate'   => 'required',
                'user'      =>'required'
            ]);
            if($validation->fails()){
               
                return redirect()->back()->with(['active'=>$active])->withInput()->withErrors($validation->messages());
            }
            
            $applications   =   $request->applications;
            $startDate      =   $request->startDate;
            $endDate        =   $request->endDate;
            $user           =   $request->user;
            $fromdate       =   $startDate;
            $todate         =   $endDate ;

          

            $users = \App\ChargingHistory::select('charging_histories.*','app_users.first_name','app_users.last_name')
            ->join('app_users','app_users.id','=','charging_histories.app_user_id')
            ->whereBetween('charging_histories.created_at', 
            array(date('Y-m-d 00:00:00',strtotime($startDate)), 
            date('Y-m-d 23:59:59',strtotime($endDate))))
            ->where('app_users.id',$user)
            ->get();
            if(!$users){
               $message= $message.' User : '.$users[0]->first_name." ".$users[0]->last_name;
            }
            view()->share(compact('applications','user','startDate','endDate','message'));
           
        }
        if($request->search=='bydate'){

            $validation = Validator::make($request->all(),[
                'startDate' => 'required',
                'endDate'   => 'required'
            ]);
            if($validation->fails()){
               
                return redirect()->back()->withInput()->withErrors($validation->messages());
            }
            $user = \App\ChargingHistory::select('charging_histories.*','app_users.first_name','app_users.last_name')
            ->join('app_users','app_users.id','=','charging_histories.app_user_id');

        $startDate      =   $request->startDate;
        $endDate        =   $request->endDate;
        $searchdata     =   $request->searchdata;
        $application    =   $request->application;
        $station        =   $request->station;
        $cps            =   $request->cps;

        $fromdate       =   $startDate;
        $todate         =   $endDate ;

      
        if(Entrust::hasRole('organisation')){
            $message=$message." & Organization Name :  ". Auth::user()->package.'  ';
            $user->where('app_users.package_name',Auth::user()->package);
        }else{
            if($application){
                    $message=$message." & Organization Name :  ". $application.'  ';
                    $report->where('application',$application);
            }
        }

        if(!empty($cps)){
            $user->where('charging_histories.nozzle_id',$cps);
            $message= $message.' OCPP ID : '.$cps;
        }

  
        $user->whereBetween('charging_histories.created_at', array(date('Y-m-d 00:00:00',strtotime($startDate)), date('Y-m-d 23:59:59',strtotime($endDate))));
        $users=$user->get();

       
    
        if($users){
            $message= $message."  Station :".$station;
         }
    
        view()->share(compact('application','cps','station','message'));
        
    
    }
        }else{
        $fromdate    = date('d-m-Y',strtotime(\Carbon\Carbon::today()->subDays(7)));
        $todate      = date('d-m-Y',strtotime(\Carbon\Carbon::today()));

        $date = \Carbon\Carbon::today()->subDays(7);
        $use = \App\ChargingHistory::select('charging_histories.*','app_users.first_name','app_users.last_name');

        if(Entrust::hasRole('organisation'))
            $use->where('app_users.package_name',Auth::user()->package);


        $users=$use->join('app_users','app_users.id','=','charging_histories.app_user_id')
        ->where('charging_histories.created_at', '>=', $date)->get();
      


        }
        return view('admin.transactions.charging_history',compact('message','charging_points','stations','packages','active','startDate','endDate','searchdata','menu','users','todate','fromdate'));
    }catch(Exception $e){
            return redirect()->back()->withErrors("something went wrong please try again later");
    }
   
    }
    // $date = \Carbon\Carbon::today()->subDays(30);

    // $users = User::where('created_at', '>=', $date)->get();
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
       // if($request->search=='bytime'){

        //     $active='bytime';
        //     $validation = Validator::make($request->all(),[
        //             'Date_time' => 'required','from_time'   => 'required','to_time'   => 'required']);
        //     if($validation->fails()){ 
        //         return redirect()->back()->withInput()->with( $active)->withErrors($validation->messages());
        //     }
        //     $startDate      =   $request->Date_time;
        //     $from_time      =   $request->from_time;
        //     $to_time        =   $request->to_time;

        //     if(strtotime($to_time)<strtotime($from_time)){
        //         return redirect()->back()->withInput()->withErrors("From to Should be more that from");
        //     }
        //     $search=true;
        //     view()->share(compact('from_time','to_time'));

        //     $message=$startDate .' and Time  '. $from_time. " To ".$to_time;
        //     $transactions->whereBetween('transactions.created_at', 
        //     array(
        //     date('Y-m-d '.$from_time.":00",strtotime($startDate)),
        //     date('Y-m-d '.$to_time.":00",strtotime($startDate))));
        //     }
    }
}
