<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use DB;
use Illuminate\Support\Facades\Input;
use Session;
use Redirect;
use View;
use Crypt;
use App\User;
use App\Profile;
use Entrust;
use App\Http\Requests\RegisterRequest;
use App\Http\Requests\UserRequest;
use App\Classes\Helper;

class UserController extends Controller
{

    protected $form = 'user-form';
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {


        if(!Entrust::can('view_users'))
        return view('common.error',['message' => trans('messages.permission_denied')]);

        $roles = \App\Role::whereIsHidden(0)->get()->pluck('name','id')->all();

        $col_heads = array(
              
                trans('messages.first_name'),
                trans('messages.last_name'),
                trans('messages.username'),
                trans('messages.email'),
                trans('messages.role'),
                trans('messages.status'),
                trans('messages.option'));
        $table_info = array(
            'source' => 'users',
            'title' => 'Employee List',
            'id' => 'employee_table',
            'form' => 'employee_filter_form'
        );
        $menu = ['admins'];
        

        
        return view('admin.admin_list.index',compact('col_heads','table_info','roles','menu'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(RegisterRequest $request, User $user)
    {


        if(!Entrust::can('create-user')){
            return redirect('/dashboard')->withErrors(trans('messages.permission_denied'));
        }
    if(!preg_match('/^[a-zA-Z0-9_\.\-]*$/',$request->input('username'))){

            return redirect()->back()->withInput($request->input())
                    ->withErrors(trans('messages.username_allowed_characters'));
        }
              if($request->has('send_welcome_email')){
            $template = \App\Template::whereCategory('welcome_email')->first();
            if(!$template){
               
         return redirect()->back()->withInput($request->input())
                    ->withErrors(trans('messages.username_allowed_characters'));
            }
        }

      try{  
          DB::beginTransaction();
        $user->fill($request->all());
        $user->password = bcrypt($request->input('password'));
        $user->status = 'active';
        $user->package = $request->package_id;
        $user->role=$request->input('role_id');
        $user->save();
        $profile = $user->Profile ?: new Profile;
        $user->profile()->save($profile);
        $user->attachRole($request->input('role_id'));

        if($request->has('send_welcome_email')){
            $template = \App\Template::whereCategory('welcome_email')->first();
            $body = $template->body;
            $body = str_replace('[NAME]',$user->full_name,$body);
            $body = str_replace('[PASSWORD]',$request->input('password'),$body);
            $body = str_replace('[USERNAME]',$user->username,$body);
            $body = str_replace('[EMAIL]',$user->email,$body);

            $mail['email'] = $user->email;
            $mail['subject'] = $template->subject;

            $blade="welcome_mail";
           
            $status =Helper::sendMails($request->email,$mail['subject'],$blade,$body);
        }
        $this->logActivity(['module' => 'admins','activity' => 'activity_added']);
        DB::commit();
        return redirect()->back()->withSuccess(trans('messages.user').' '.trans('messages.added'));

    }catch(Exception $e){
        DB::rollback();
        return Redirect()->back()->withErrors(trans('messages.something_wrong'));
    }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {

     
        if(!Entrust::can('edit-user')){
            $response = ['message' => trans('messages.permission_denied'), 'status' => 'error']; 
            return response()->json($response, 200, array('Access-Controll-Allow-Origin' => '*'));
            }
        
        $menu = ['admins'];

        foreach($user->roles as $role)
        $role_id = $role->id;
        if(defaultRole())
        $roles = \App\Role::pluck('name','id')->all();
    else
        $roles = \App\Role::where('name','!=','admin')->pluck('name','id')->all();

        $gender = Helper::translateList(config('lists.gender'));

        $custom_field_values = Helper::getCustomFieldValues($this->form,$user->id);
        return view('admin.admin_list.edit',compact('user','roles','role_id','gender','menu','custom_field_values'));
    }
//display data into table using AJAX Request
    public function lists(Request $request){


        if(!Entrust::can('view_users')){
            return redirect('/dashboard')->withErrors(trans('messages.permission_denied'));
        }

        $columns = array( 
            0 =>'first_name',
            1=> 'last_name',
            2=> 'username',
            3=> 'email',
            4=> 'status',
            5=> 'status',
            6=> 'status',
 
        );

    $totalData = \App\User::count();

    $totalFiltered = $totalData; 

    $limit = $request->input('length');
    $start = $request->input('start');
    $order = $columns[$request->input('order.0.column')];
    $dir = $request->input('order.0.dir');

    if(empty($request->input('search.value')))
    {            
    $user = \App\User::offset($start)
            ->limit($limit)
            ->orderBy($order,$dir)
            ->get();
    }
else {
$search = $request->input('search.value'); 

$user =  \App\User::where('username','LIKE',"%{$search}%")
            ->orWhere('first_name', 'LIKE',"%{$search}%")
            ->orWhere('last_name', 'LIKE',"%{$search}%")
            ->orWhere('email', 'LIKE',"%{$search}%")
            ->orWhere('status', 'LIKE',"%{$search}%")
            ->offset($start)
            ->limit($limit)
            ->orderBy($order,$dir)
            ->get();

$totalFiltered = \App\User::where('username','LIKE',"%{$search}%")
             ->orWhere('first_name', 'LIKE',"%{$search}%")
             ->orWhere('last_name', 'LIKE',"%{$search}%")
             ->orWhere('email', 'LIKE',"%{$search}%")
             ->orWhere('status', 'LIKE',"%{$search}%")
             ->count();
}
$rows=[];
    $data = array();
    $i=1;
    if(!empty($user))
    {
        $i=1;
    foreach ($user as $users){
        foreach($users->roles as $role)
        $role_name = Helper::toWord($role->name);
        if($users->id!=7){
        
        $rows[] = array(
         $users->first_name,
         $users->last_name,
         $users->username.' '.(($users->is_hidden) ? '<span class="label label-danger">'.trans('messages.default').'</span>' : ''),
           
         $users->email,
         $role_name,
         ($users->status == 'active' || $users->status == '') ? '<span class="label label-success">'.trans('messages.active').'</span>' : '<span class="label label-danger">'.Helper::toWord($users->status).'</span>'
         , '<div class="btn-group btn-group-xs">'.
         '<a href="/users/'.$users->id.'/edit" class="btn btn-xs btn-default" > <i class="fa fa-edit" data-toggle="tooltip" title="'.trans('messages.edit').'"></i></a> '.
         (($users->status != 'in-active') ? '<a href="#" data-href="/users/'.Crypt::encrypt($users->id).'/change-status" class="btn btn-default btn-xs edit-form" data-toggle="modal" data-target="#mymodel"> <i class="fa fa-user" data-toggle="tooltip" title="'.trans('messages.change').' '.trans('messages.status').'"></i></a> ' : '').
         (Entrust::can('delete-user') ? delete_form(['users.destroy',$users->id],'users',1) : '').
         '</div>',);;  
          $i++;
        }
        }
}
$json_data = array(
    "draw"            => intval($request->input('draw')),  
    "recordsTotal"    => intval($totalData),  
    "recordsFiltered" => intval($totalFiltered), 
    "aaData"            => $rows   
    );
echo json_encode($json_data); 
        
    }
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UserRequest $request, User $user)
    {
       

       
        if(!Entrust::can('edit-user')){
           
            return Redirect()->back()->withErrors(trans('messages.permission_denied'));
        }
        
        if(!preg_match('/^[a-zA-Z0-9_\.\-]*$/',$request->input('username'))){
          
            return redirect('/dashboard')->withErrors(trans('messages.username_allowed_characters'));
        }

        if($request->has('password')){
           if($request->password==$request->password_confirmation){
            $user->password = bcrypt($request->input('password'));
           }else{
            return Redirect()->back()->withErrors(trans('Password And Confirm Password Should be same'));
           }
        }

        $user->first_name = $request->input('first_name');
        $user->last_name = $request->input('last_name');
        $user->username = $request->input('username');
        $user->email = $request->input('email');
        $user->mobile = $request->input('mobile');
        $user->package = $request->input('package_id');

    try{    
        DB::beginTransaction();
        if(defaultRole() && $request->has('role_id')){
          $roles[] = $request->input('role_id');
          $user->roles()->sync($roles);
        }
        $user->save();

        $profile = $user->Profile ?: new Profile;
        $profile->gender = $request->input('gender');


        
        $user->profile()->save($profile);
        $this->logActivity(['module' => 'admins','unique_id'=>$user->id,'activity' => 'activity_updated']);
        DB::commit();
        return redirect('/users/'.$user->id.'/edit')->withSuccess(trans('messages.user').' '.trans('messages.updated'));

    }catch(Exception $e){
        DB::rollback();
        return Redirect()->back()->withErrors(trans('messages.something_wrong'));
    }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {

        try{
       $user=User::find($id);
       if(!$user || Entrust::can('delete_user')){
            return view('common.error',['message' => trans('messages.permission_denied')]);
       }
            $user->profile->delete();
            $user->delete();
            $this->logActivity(['module' => 'admins','unique_id'=>$id,'activity' => 'activity_deleted']);

            return redirect('/users')->withSuccess(trans('messages.user').'  '.trans('messages.deleted'));
    }catch(Exception $e){
            return Redirect()->back()->withErrors(trans('messages.something_wrong'));
    }
    }

    public function changeStatus($id){
        $id=Crypt::decrypt($id);
        $user = \App\User::find($id);

        if(!$user || Entrust::can('change-user-status') || $user->status == 'in-active')
            return view('common.error',['message' => trans('messages.permission_denied')]);

        return view('admin.admin_list.change_status',compact('user'));

        
    }
    public function postChangeStatus(Request $request, $id){


        try{

            DB::beginTransaction();
        $user = \App\User::find($id);

        $validation = Validator::make($request->all(),[
            'status' => 'required'
        ]);

        if($validation->fails()){
           
            return redirect()->back()->withErrors($validation->messages()->first());
        }

        $user->status = $request->input('status');
        $user->save();
        $this->logActivity(['module' => 'admins','unique_id'=>$id,'activity' => 'status_updated']);
        DB::commit();
        return redirect('/users')->withSuccess(trans('messages.user').' '.trans('messages.status').' '.trans('messages.updated'));
   
   
    }catch(Exception $e){
        DB::rollback();
        return Redirect()->back()->withErrors(trans('messages.something_wrong'));
    }
   
    }

}
